@@ -34,7 +34,9 @@ from prompt_toolkit.styles import Style
 from prompt_toolkit.widgets import Dialog, MenuContainer, MenuItem, SearchToolbar, TextArea
 from prompt_toolkit.widgets.base import Border, Button, Label
 
-ABOUT_MESSAGE = """QuickPython version 0.0.2
+from quickpython import __version__
+
+ABOUT_MESSAGE = f"""QuickPython version {__version__}
 
 Copyright (c) 2020 Timothy Crosley. Few rights reserved. MIT Licensed.
 Simultanously distributed to the US and Canada.
@@ -66,7 +68,6 @@ style = Style.from_dict(
         "scrollbar.background": "bg:#AAAAAA",
         "scrollbar.button": "bg:black fg:black",
         "scrollbar.arrow": "bg:#AAAAAA fg:black bold",
-        # "button": "bg:#AAAAAA fg:#000000",
         "": "bg:#0000AA fg:#AAAAAA bold",
     }
 )
@@ -308,10 +309,12 @@ def save_file(event=None):
     immediate.buffer.text = f"Successfully saved {current_file}"
 
 
-async def _run_buffer():
+async def _run_buffer(debug: bool = False):
     buffer_filename = f"{current_file or 'buffer'}.qpython"
     with open(buffer_filename, "w") as buffer_file:
         buffer_file.write(app.current_buffer.text)
+        if debug:
+            buffer_file.write("breakpoint()")
 
     try:
         clear()
@@ -331,6 +334,10 @@ def run_buffer(event=None):
     asyncio.ensure_future(_run_buffer())
 
 
+def debug():
+    asyncio.ensure_future(_run_buffer(debug=True))
+
+
 def view_buffer(event=None):
     asyncio.ensure_future(_view_buffer())
 
@@ -807,7 +814,10 @@ root_container = MenuContainer(
                 MenuItem("Change", handler=replace_text),
             ],
         ),
-        MenuItem(" Run ", children=[MenuItem("Start (F5)", handler=run_buffer)]),
+        MenuItem(
+            " Run ",
+            children=[MenuItem("Start (F5)", handler=run_buffer), MenuItem("Debug", handler=debug)],
+        ),
         MenuItem(
             " Help ",
             children=[MenuItem("About", handler=about)],
